// Copyright (C) 2009 Playedit.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef MUSIC_H
#define MUSIC_H

#include "treeview.h"
#include "app_window.h"

class MusicView : public DNDTreeViewBase
{
	public:
		MusicView(Playedit::App& app_window);

		void PopulateStore(const std::vector<album_pair_t>& album_list);

		// Music actions
		void EditAlbumMetadata();
		void AddAlbumArt();
		void EditTrackMetadata();
		void DeleteTracksFromDevice();
		void DeleteAlbumsFromDevice();

		// Music sort actions
		void SetSortByName();
		void SetSortByArtist();

	private:
		void AlbumArtDataFunc(Gtk::CellRenderer *renderer,
				const Gtk::TreeIter& iter);
		void MusicNameDataFunc(Gtk::CellRenderer *renderer,
				const Gtk::TreeIter& iter);
		bool SelectionFunc(const Glib::RefPtr<Gtk::TreeModel>& model,
				const Gtk::TreePath& path, bool path_currently_selected);
		void SelectSortTypePopup();
		int SortByName(const Gtk::TreeIter& a, const Gtk::TreeIter& b);
		int SortByArtist(const Gtk::TreeIter& a, const Gtk::TreeIter& b);
		bool on_button_press_event(GdkEventButton* event);
		void SelectionChanged();
		void on_drag_begin(const Glib::RefPtr<Gdk::DragContext>& context);
		bool on_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context,
				int x, int y, guint time);
		void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
				int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time);
		void FindAlbumAndAddTrack(Glib::RefPtr<track_t>& track);

		Gtk::CellRendererPixbuf m_AlbumArt;
		Gtk::CellRendererText m_MusicName;
		Playedit::App& m_App;
};

#endif // MUSIC_H
